{#- OZI 0.2
# ozi/templates/github_workflows/ozi.yml.j2
# SPDX-License-Identifier: Unlicense
-#}
{%- for line in project.copyright_head.split('\n') %}
{{ '# ' ~ line }}
{%- endfor %}
{{ '# Additional copyright and license terms apply, see NOTICE for details.' }}
name: OZI

on:
  push:
    branches:
      - "v?[0-9].[0-9]*"
      - "v?[1-9]+[0-9].[0-9]*"

permissions:
  contents: read

jobs:

{% include 'github_workflows/checkpoint.yml.j2' %}

{% include 'github_workflows/draft.yml.j2' %}

{% include 'github_workflows/release.yml.j2' %}

{% include 'github_workflows/generate_provenance.yml.j2' %}

{% include 'github_workflows/publish.yml.j2' %}