{#- OZI 0.1
# ozi/templates/tests/meson.build.j2
# SPDX-License-Identifier: Unlicense
-#}
{{ '# OZI ' ~ spec.version }} meson.build:test_files,test_children
{%- for line in project.copyright_head.split('\n') %}
{{ '# ' ~ line }}
{%- endfor %}
{{ '# DO NOT EDIT BY HAND - This file was generated for use with OZI tools.' }}
{{ '# ozi-fix -> meson rewrite is the standard editing pipeline.' }}
test_files = []
foreach file: test_files
    fs.copyfile(file)
    if not meson.is_subproject() or get_option('install-subprojects').enabled()
        python.install_sources(file, subdir: '{{ project.name|underscorify|lower }}' / 'tests')
    endif
endforeach
test_children = []
foreach child: test_children
    subdir(child)
endforeach
